﻿using System;
using System.Collections.Generic;
using GTA;
using GTA.Native;
using GTA.Math;

namespace GTAV_F14Helper
{
    public class F14Helper : Script
    {
        private Tomcat mainVehicle;
        private CarpetBomb cBomb, cBomb1;

        public F14Helper()
        {
            mainVehicle = null;
            Tick += OnTick;
        }

        private void OnTick(object sender, EventArgs e)
        {
            var player = Game.Player.Character;

            if (mainVehicle != null && !player.IsInVehicle(mainVehicle.Vehicle))
            {
                if (mainVehicle.BombCam != null)
                    mainVehicle.ToggleBombBayView();

                cBomb.DestroyActiveBombs();
                cBomb1.DestroyActiveSounds();
                mainVehicle.KillAfterburner();
                mainVehicle = default(Tomcat);
            }

            if (player.IsInVehicle() && player.CurrentVehicle.Model == VehicleHash.Lazer)
            {
                if ((mainVehicle == null || mainVehicle.Handle != player.CurrentVehicle.Handle))
                {
                    mainVehicle = new Tomcat(player.CurrentVehicle);
                    mainVehicle.InitializeAfterburner();
                    cBomb = new CarpetBomb(mainVehicle.Vehicle, new Vector3(-0.6f, 0, -1f));
                    cBomb1 = new CarpetBomb(mainVehicle.Vehicle, new Vector3(0.6f, 0, -1f));
                    
                }

                else if (mainVehicle.Vehicle.IsDriveable)
                {
                    cBomb.Update();
                    cBomb1.Update();
                    mainVehicle.Update();

                    Control ctlToggleWing, ctlToggleView, ctlAttack;

                    if (Function.Call<bool>(Hash._GET_LAST_INPUT_METHOD, 2))
                    {
                        ctlToggleWing = Control.SelectWeaponMelee;
                        ctlToggleView = Control.SelectWeaponUnarmed;
                        ctlAttack = Control.VehicleFlyAttack2;
                    }

                    else
                    {
                        ctlToggleWing = Control.ScriptRS;
                        ctlToggleView = Control.ScriptPadRight;
                        ctlAttack = Control.ScriptRDown;
                    }

                    if (Game.IsControlJustPressed(0, ctlToggleWing))
                    {
                        mainVehicle.ToggleWingState();                       
                    }

                    if (Game.IsControlJustPressed(0, ctlToggleView))
                    {
                        mainVehicle.ToggleBombBayView();
                    }

                    if (Game.IsControlJustPressed(0, ctlAttack) && mainVehicle.BombCam != null)
                    {
                        cBomb.StartBombingSequence();
                        Wait(150);
                        cBomb1.StartBombingSequence();
                    }
                }
            }
        }

        protected override void Dispose(bool A_0)
        {
            World.RenderingCamera = null;
            Function.Call(Hash.DISPLAY_RADAR, true);
            Function.Call(Hash.DISPLAY_HUD, true);
            Function.Call(Hash.DESTROY_ALL_CAMS, false);

            if (cBomb != null)
            {
                cBomb.DestroyActiveBombs();
                cBomb.DestroyActiveSounds();
            }

            if (cBomb1 != null)
            {
                cBomb1.DestroyActiveBombs();
                cBomb1.DestroyActiveSounds();
            }

            mainVehicle?.KillAfterburner();

            base.Dispose(A_0);
        }
    }


   
}
